"""
drawing_type_instances.py
"""
population = [
    # Diagram types
    {'Name': 'Starr class diagram'},
    {'Name': 'xUML class diagram'},
    {'Name': 'Shlaer-Mellor class diagram'},

    {'Name': 'xUML state machine diagram'},

    {'Name': 'Starr class collaboration diagram'},
    {'Name': 'xUML class collaboration diagram'},

    {'Name': 'Starr domain diagram'},
    {'Name': 'xUML domain diagram'},

    # Frame styles
    {'Name': 'OS Engineer large frame'},   # For large sheet sizes (D, E, A2-A0)
    {'Name': 'OS Engineer medium frame'},  # For medium sheet sizes (tabloid, C, A3)
    {'Name': 'OS Engineer small frame'},  # For small sheet sizes (letter, A4)
    {'Name': 'TRI MBSE large frame'},  # For large sheet sizes (D, E, A2-A0)
    {'Name': 'TRI MBSE medium frame'},  # For medium sheet sizes (tabloid, C, A3)
    {'Name': 'TRI MBSE small frame'},  # For small sheet sizes (letter, A4)

    # Diagnostic
    {'Name': 'Grid Diagnostic'},  # To display a grid of rows and columns
]